@@ -1,6 +1,6 @@
 r""" __init__.py - Parse, Query, Build, and Modify IOS-style configurations
 
-     Copyright (C) 2021      David Michael Pennington
+     Copyright (C) 2021-2022 David Michael Pennington
      Copyright (C) 2020-2021 David Michael Pennington at Cisco Systems
      Copyright (C) 2019      David Michael Pennington at ThousandEyes
      Copyright (C) 2012-2019 David Michael Pennington at Samsung Data Services
@@ -21,12 +21,18 @@ r""" __init__.py - Parse, Query, Build, and Modify IOS-style configurations
      along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
      If you need to contact the author, you can do so by emailing:
-     mike [~at~] pennington [/dot\] net
+     mike [~at~] pennington [.dot.] net
 """
 
-from __future__ import absolute_import
+import sys
+
+from ciscoconfparse.ccp_util import PythonOptimizeCheck
 from ciscoconfparse.ciscoconfparse import *
 from ciscoconfparse.ccp_util import *
 
-# pyproject.toml needs version defined in __init__.py...
-# See the imports above...
+assert sys.version_info >= (3, 6)
+
+
+# Throw errors for PYTHONOPTIMIZE and `python -O ...` by executing
+#     PythonOptimizeCheck()...
+_ = PythonOptimizeCheck()
